function ofm = gen_ofm(N, w0)

%% =================================================================
%% GENERADOR DE ONDÍCULA DE FASE MÍNIMA
%% =================================================================
%%
%% ofm = gen_ofm(N, w0)
%%
%% ENTRADA
%%
%% N:   [ms] número de muestras
%% w0:  [rad/muestra] frecuencia máxima
%%
%% SALIDA
%%
%% ofm:  ondícula de fase mínima en tiempo
%%
%% EJEMPLO
%%
%% ofm = gen_ofm(40, pi/3)
%% 

dW = w0/N ; % paso en frecuencia
ofm(N) = 0.

% Generamos una ondícula de fase mínima y le aplicamos un taper de Hamming:
for n = 0:N-1
    hamm(n+1) = 0.54 - 0.46*cos(pi*(N-1-n)/(N-1));  % taper de Hamming
    ofm(n+1)  = hamm(n+1)*(0.8^n)*cos((w0-dW*n)*n); % ondicula de fase mín.
end

end
